document.addEventListener('DOMContentLoaded', () => {
    const jsonInput = document.getElementById('jsonInput');
    const jsonOutput = document.getElementById('jsonOutput');
    const formatBtn = document.getElementById('formatBtn');

    const formatJSON = () => {
        const input = jsonInput.value.trim();
        
        if (!input) {
            jsonOutput.textContent = '';
            return;
        }

        try {
            const parsed = JSON.parse(input);
            const formatted = JSON.stringify(parsed, null, 2);
            jsonOutput.textContent = formatted;
            jsonOutput.classList.remove('error');
        } catch (error) {
            jsonOutput.textContent = `Error: ${error.message}`;
            jsonOutput.classList.add('error');
        }
    };

    formatBtn.addEventListener('click', formatJSON);
    
    // Auto-format as user types with debounce
    let timeout;
    jsonInput.addEventListener('input', () => {
        clearTimeout(timeout);
        timeout = setTimeout(formatJSON, 500);
    });

    // Add keyboard shortcut (Ctrl/Cmd + Enter)
    jsonInput.addEventListener('keydown', (e) => {
        if ((e.ctrlKey || e.metaKey) && e.key === 'Enter') {
            formatJSON();
        }
    });
});